==> istio-model-v1alpha3-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashLBFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface LoadBalancerSettingsConsistentHashLBFluent<A extends LoadBalancerSettingsConsistentHashLBFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildHashKey instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsLoadBalancerSettingsConsistentHashLBHashKey getHashKey();
  public IsLoadBalancerSettingsConsistentHashLBHashKey buildHashKey();
  public A withHashKey(IsLoadBalancerSettingsConsistentHashLBHashKey hashKey);
  public Boolean hasHashKey();
  public A withLoadBalancerSettingsConsistentHashLBHttpCookieKey(LoadBalancerSettingsConsistentHashLBHttpCookie loadBalancerSettingsConsistentHashLBHttpCookieKey);
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpCookieKey();
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpCookieKeyLike(LoadBalancerSettingsConsistentHashLBHttpCookie item);
  public A withLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey(LoadBalancerSettingsConsistentHashLBHttpHeaderName loadBalancerSettingsConsistentHashLBHttpHeaderNameKey);
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey();
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyLike(LoadBalancerSettingsConsistentHashLBHttpHeaderName item);
  public A withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey(String httpHeaderName);
  public A withLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName loadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey);
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey();
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyLike(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName item);
  public A withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey(String httpQueryParameterName);
  public A withLoadBalancerSettingsConsistentHashLBUseSourceIpKey(LoadBalancerSettingsConsistentHashLBUseSourceIp loadBalancerSettingsConsistentHashLBUseSourceIpKey);
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKey();
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKeyLike(LoadBalancerSettingsConsistentHashLBUseSourceIp item);
  public A withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKey(Boolean useSourceIp);
  public Integer getMinimumRingSize();
  public A withMinimumRingSize(Integer minimumRingSize);
  public Boolean hasMinimumRingSize();
  public interface LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<N> extends Nested<N>,LoadBalancerSettingsConsistentHashLBHttpCookieFluent<LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsConsistentHashLBHttpCookieKey();
    
  }
  public interface LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<N> extends Nested<N>,LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey();
    
  }
  public interface LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<N> extends Nested<N>,LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey();
    
  }
  public interface LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<N> extends Nested<N>,LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsConsistentHashLBUseSourceIpKey();
    
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashLBFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;

 /**
  * Generated
  */
public interface LoadBalancerSettingsConsistentHashLBFluent<A extends LoadBalancerSettingsConsistentHashLBFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildHashKey instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsLoadBalancerSettingsConsistentHashLBHashKey getHashKey();
  public IsLoadBalancerSettingsConsistentHashLBHashKey buildHashKey();
  public A withHashKey(IsLoadBalancerSettingsConsistentHashLBHashKey hashKey);
  public Boolean hasHashKey();
  public A withLoadBalancerSettingsConsistentHashLBHttpCookieKey(LoadBalancerSettingsConsistentHashLBHttpCookie loadBalancerSettingsConsistentHashLBHttpCookieKey);
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpCookieKey();
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpCookieKeyLike(LoadBalancerSettingsConsistentHashLBHttpCookie item);
  public A withLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey(LoadBalancerSettingsConsistentHashLBHttpHeaderName loadBalancerSettingsConsistentHashLBHttpHeaderNameKey);
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey();
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyLike(LoadBalancerSettingsConsistentHashLBHttpHeaderName item);
  public A withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey(String httpHeaderName);
  public A withLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName loadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey);
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey();
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyLike(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName item);
  public A withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey(String httpQueryParameterName);
  public A withLoadBalancerSettingsConsistentHashLBUseSourceIpKey(LoadBalancerSettingsConsistentHashLBUseSourceIp loadBalancerSettingsConsistentHashLBUseSourceIpKey);
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKey();
  public LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKeyLike(LoadBalancerSettingsConsistentHashLBUseSourceIp item);
  public A withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKey(Boolean useSourceIp);
  public Integer getMinimumRingSize();
  public A withMinimumRingSize(Integer minimumRingSize);
  public Boolean hasMinimumRingSize();
  public interface LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<N> extends Nested<N>,LoadBalancerSettingsConsistentHashLBHttpCookieFluent<LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsConsistentHashLBHttpCookieKey();
    
  }
  public interface LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<N> extends Nested<N>,LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey();
    
  }
  public interface LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<N> extends Nested<N>,LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey();
    
  }
  public interface LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<N> extends Nested<N>,LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<LoadBalancerSettingsConsistentHashLBFluent.LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<N>>{
    public N and();
    public N endLoadBalancerSettingsConsistentHashLBUseSourceIpKey();
    
  }
  
}
